import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.0

Item {
    //property alias decleration ------

    //main.qml (most of them called by Python)
    property alias resetDialog: resetDialog
    property alias savedSuccessDialog: savedSuccessDialog
    property alias loadedSuccessfulDialog: loadedSuccessfulDialog
    property alias deletedSuccessfulDialog: deletedSuccessfulDialog
    property alias noDataDialog: noDataDialog
    property alias timePickerDialog: timePickerDialog

    //MainPage.qml
    property alias timeOutDialog: timeOutDialog

    //SavePage.qml
    property alias loadDialog: loadDialog
    property alias deleteDialog: deleteDialog
    property alias deleteSafetyDialog: deleteSafetyDialog


    //components ----------------------

    //main.qml
    QueryDialog {
        id: resetDialog
        titleText: "Reset"
        message: "Do you really want to reset the counter?"
        acceptButtonText: "Yes"
        rejectButtonText: "No"

        onAccepted: {
            mainPage.timer.stop(); mainPage.countDown.stop();
            mainPage.zahl = "0"; mainPage.time = 0; mainPage.countdownText = ""
        }
    }

    QueryDialog {
        id: savedSuccessDialog
        titleText: "Saved!"
        message: "Your data was saved successfully."
        acceptButtonText: "Okay"
    }

    QueryDialog {
        id: loadedSuccessfulDialog
        titleText: "Loaded!"
        message: "Your data was loaded successfully."
        acceptButtonText: "Okay"
    }

    QueryDialog {
        id: deletedSuccessfulDialog
        titleText: "Data deleted!"
        message: "Your data was deleted successfully."
        acceptButtonText: "Okay"
    }

    QueryDialog {
        id: noDataDialog
        titleText: "Warning!"
        message: "There is no data available. It seems, that you've never stored a result bevor."
        acceptButtonText: "Okay"
    }

    TimePickerDialog{
           id: timePickerDialog
           titleText: "Select time..."
           acceptButtonText: "Confirm"
           rejectButtonText: "Reject"
           onAccepted: {
               timePickerAccepted()
       }
    }

    //MainPage.qml
    QueryDialog {
        id: timeOutDialog
        titleText: "Timeout"
        message: "The timer stopped. Press 'Again' to use the counter again for the selected duration. Press 'Cancel' to switch back to the normal counting mode."
        acceptButtonText: "Again"
        rejectButtonText: "Cancel"
        onAccepted: {countdownTime = time; showTimerOnUI()}
        onRejected: {zahl.text = "0"; countdownText.text = ""; time = 0}
    }

    //SavePage.qml
    SelectionDialog {
        id: loadDialog
        titleText: "Load data"
        selectedIndex: 0
        model: dataList
        onAccepted: {
            pyfunc.loadData(loadDialog.selectedIndex)
            loadDialog.selectedIndex = 0 //to prevent that selection disappears (QML Bug)
        }
    }

    SelectionDialog {
        id: deleteDialog
        titleText: "Delete data"
        selectedIndex: 0
        model: dataList

        onAccepted: {
            deleteSafetyDialog.open()
        }
    }

    QueryDialog {
        id: deleteSafetyDialog
        titleText: "Sure?"
        message: "You are sure, that you want to delete this element?"
        acceptButtonText: "Yes"
        rejectButtonText: "Cancel"

        onAccepted: {
            pyfunc.deleteData(deleteDialog.selectedIndex)
            deleteDialog.selectedIndex = 0 //to prevent that selection disappears (QML Bug)
        }

        onRejected: {
            deleteDialog.selectedIndex = 0 //to prevent that selection disappears (QML Bug)
        }
    }
}
