import QtQuick 1.1
import QtMultimediaKit 1.1
import QtMobility.feedback 1.1
import com.nokia.meego 1.0

Page {
    orientationLock: PageOrientation.LockPortrait
    tools: commonTools

    property alias counterSign: counterSign.text
    property alias zahl: zahl.text
    property alias countdownText: countdownText.text
    property alias timer: timer
    property alias countDown: countDown
    property string calc: "+"   
    property bool sound: true
    property bool vibra: true
    property int stepSize: 1
    property int time: 0
    property int countdownTime: 0

    Dialogs {
        id: dialogs
        }

    Rectangle {
        id: counterBG
        anchors.top: parent.top
        width: parent.width
        height: 150
        color: "black"
    }

    Text {
        id: zahl
        anchors {right: parent.right; rightMargin: 20; verticalCenter: counterBG.verticalCenter}
        text: "0"
        color: "white"
        font {family: "Nokia Pure Text Light"; pointSize: 90}
    }

    Rectangle {
        id: countButton
        anchors.top: counterBG.bottom
        width: parent.width
        height: parent.height - counterBG.height
        color: "darkgrey"

    }

    MouseArea {
        id: clicker
        anchors.fill: parent        
        onClicked: {          
            //Timer start
            if ((time !== 0) && (timer.running === false)) {timer.start(); countDown.start()}

            //Feedback features
            if (vibra === true){rumbleEffect.start()};  // plays a rumble effect
            if (sound === true){playSound.play()} //plays a sound effect

            //Count features
            var count = parseInt(zahl.text)
            if (calc === "+"){count += stepSize}
            else {count -= stepSize}
            zahl.text = count
        }
    }

    Button {
        id: countdownPause
        anchors {left: parent.left; leftMargin: 18; bottom: parent.bottom; bottomMargin: 10}
        width: 45
        height: 45
        visible: time === 0 ? false : true
        platformStyle: ButtonStyle {inverted: true}
        iconSource: timer.running ? "/usr/share/themes/blanco/meegotouch/icons/icon-m-lockscreen-mediacontrol-pause.png" : "/usr/share/themes/blanco/meegotouch/icons/icon-m-lockscreen-mediacontrol-play.png"
        font {family: "Nokia Pure Text"; bold: true}

        onClicked: {
            timer.running ? timer.stop() : timer.start()
            countDown.running ? countDown.stop() : countDown.start()
        }
    }

    Text {
        id: countdownText
        anchors {left: countdownPause.right; leftMargin: 10; bottom: clicker.bottom; bottomMargin: 15}
        text: ""
        font {family: "Nokia Pure Text"; pointSize: 24; bold: true}
        color: "black"
    }

        Text {
            id: counterSign
            anchors.centerIn: clicker
            text: calc == "+" ? "+" : "-"
            font {family: "Nokia Pure Text Light"; pointSize: 150}
            color: clicker.pressed ? "white": "lightgrey"
        }

        Timer {
            id: timer
            interval: time
        }

        Timer {
            id: countDown
            interval: 1000
            repeat: true
            onTriggered: {
                //here is -1000 to counter the first interval of 1000ms
                var ms = countdownTime-1000

                //transform ms in normal time
                ms /= 1000
                var seconds = ms % 60
                ms /= 60
                var minutes = ms % 60
                ms /= 60
                var hours = ms % 60

                //prevent to show xx.xxxxxxxxxxxx numbers
                if (seconds.toString().length > 2){seconds = seconds.toString().substr(0,2)}
                if (minutes.toString().length > 2){minutes = minutes.toString().substr(0,2)}
                if (hours.toString().length > 2){hours = hours.toString().substr(0,2)}

                //to show time always in 00:00:00 style
                if (seconds < 10){seconds = "0"+seconds.toString().substr(0,1)}
                if (minutes < 10){minutes = "0"+minutes.toString().substr(0,1)}
                if (hours < 10){hours = "0"+hours.toString().substr(0,1)}

                countdownText.text = "Timer: "+hours+":"+minutes+":"+seconds

                //now count really down ;)
                countdownTime -=1000
                if(countdownTime <= 0){timer.stop(); countDown.stop(); dialogs.timeOutDialog.open()}
            }
         }

        SoundEffect {
                 id: playSound
                 source: "/usr/share/sounds/ui-tones/snd_default_beep.wav"
             }

        HapticsEffect {
             id: rumbleEffect
             attackIntensity: 0.0
             attackTime: 250
             intensity: 1.0
             duration: 100
             fadeTime: 250
             fadeIntensity: 0.0
         }
    }
