import QtQuick 1.1
import com.nokia.meego 1.0

PageStackWindow {
    id: appWindow
    initialPage: mainPage

    //functions, that are called from Python and "only" UI related
    function savedSuccessful() {
        dialogs.savedSuccessDialog.open()
        savePage.saveNameField = ""
        pageStack.pop()
    }

    function deletedSuccessful() {
        dialogs.deletedSuccessfulDialog.open()
    }

    function noData(){
        dialogs.noDataDialog.open()
    }

    function set_loadedData(loadedResult, loadedTimeReal, loadedTime){
        mainPage.zahl = loadedResult
        if(loadedTime !== 0){mainPage.countdownText = "Timer: "+loadedTimeReal}
        if(loadedTime === 0){mainPage.countdownText = ""}
        mainPage.time = loadedTime
        mainPage.countdownTime = loadedTime
        dialogs.loadedSuccessfulDialog.open()
        pageStack.pop()
    }

    //three functions that are used by QML for showing listData and Timer
    function create_dataList(listName, listNum, listTime) {
            var i = 0
            savePage.dataList.clear()
            for (i = 0; i<listName.length; i++){
                savePage.dataList.append({"name": listName[i]+" | "+listNum[i]+" | "+listTime[i]})
            }
    }

    function timePickerAccepted(){
        //transform selection to miliseconds
        var pickedHour = dialogs.timePickerDialog.hour * 3600000
        var pickedMinutes = dialogs.timePickerDialog.minute * 60000
        var pickedSeconds = dialogs.timePickerDialog.second * 1000

        mainPage.time = pickedHour+pickedMinutes+pickedSeconds
        mainPage.countdownTime = pickedHour+pickedMinutes+pickedSeconds

        showTimerOnUI()
    }

    function showTimerOnUI(){
        var ms = mainPage.countdownTime

        //transform ms in normal time
        ms /= 1000
        var seconds = ms % 60
        ms /= 60
        var minutes = ms % 60
        ms /= 60
        var hours = ms % 60

        //prevent to show xx.xxxxxxxxxxxx numbers
        if (seconds.toString().length > 2){seconds = seconds.toString().substr(0,2)}
        if (minutes.toString().length > 2){minutes = minutes.toString().substr(0,2)}
        if (hours.toString().length > 2){hours = hours.toString().substr(0,2)}

        //to show time always in 00:00:00 style
        if (seconds < 10){seconds = "0"+seconds.toString().substr(0,1)}
        if (minutes < 10){minutes = "0"+minutes.toString().substr(0,1)}
        if (hours < 10){hours = "0"+hours.toString().substr(0,1)}

        mainPage.countdownText = "Timer: "+hours+":"+minutes+":"+seconds
    }

//-------------------------------------------------------------------------------------------------

    MainPage {
        id: mainPage
    }

    SettingsPage {
        id: settingsPage
    }

    SavePage {
        id: savePage
    }

    Dialogs {
        id: dialogs
    }

    ToolBarLayout {
        id: commonTools
        visible: true
        ToolIcon {
            platformIconId: "toolbar-refresh"
            anchors.left: (parent === undefined) ? undefined : parent.left
            onClicked: dialogs.resetDialog.open()
        }

        ToolIcon {
            platformIconId: "toolbar-callhistory"
            onClicked: {
                if (mainPage.calc == "+") {mainPage.calc = "-"; mainPage.counterSign = "-"}
                else {mainPage.calc = "+"; mainPage.counterSign = "+"}
            }
        }

        ToolIcon {
            platformIconId: "toolbar-clock"
            onClicked: {
                dialogs.timePickerDialog.open()
            }
        }

        ToolIcon {
            platformIconId: "toolbar-directory-move-to"
            onClicked: {
                pageStack.push(savePage); mainPage.timer.stop(); mainPage.countDown.stop()
            }
        }

        ToolIcon {
            platformIconId: "toolbar-settings"
            anchors.right: (parent === undefined) ? undefined : parent.right
            onClicked: {
                pageStack.push(settingsPage); mainPage.timer.stop(); mainPage.countDown.stop()
            }
        }
    }
}
